# coding=UTF-8
def getOrPost(postString,getOrPost,url):
    import json
    try:
        import requests
    except ModuleNotFoundError:
        return "<ERROR 3>无法在未安装requests库的情况下爬虫，请在cmd/Terminal中输入pip[版本] install requests安装，如pip3.8 install requests"
    if getOrPost=='get':
        try:
            getReturn=requests.get(url)
        except requests.exceptions.MissingSchema:
            return "<ERROR 1> 必须添加网址前缀https://"
        return getReturn.text.encode(getReturn.encoding).decode(getReturn.apparent_encoding)
    else:
        try:
            postDictionary=json.loads(postString)
        except json.decoder.JSONDecodeError:
            return "<ERROR 2>在转换成json时出现错误，函数自动退出"
        try:
            postReturn=requests.post(url=url,data=postDictionary)
        except requests.exceptions.MissingSchema:
            return "<ERROR 1> 必须添加网址前缀https://"
        return postReturn.text.encode(postReturn.encoding).decode(postReturn.apparent_encoding)




import setuptools

with open("README.md","r") as fh:
    long_description=fh.read()

setuptools.setup(
    name="req_iab",
    description="I_am_back的requests项目",
    author="I_am_back",
    author_email="2682786816@qq.com",
    version="1.3",
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Natural Language :: Chinese (Simplified)",
        "Development Status :: 6 - Mature",
    ],
    packages=setuptools.find_packages(),
)
